[−][src]Enum unicode_types::arabic_extended_a::ArabicExtendedA
An enum to represent all characters in the ArabicExtendedA block.
Variants
ArabicLetterBehWithSmallVBelow\u{8a0}: 'ࢠ'
ArabicLetterBehWithHamzaAbove\u{8a1}: 'ࢡ'
ArabicLetterJeemWithTwoDotsAbove\u{8a2}: 'ࢢ'
ArabicLetterTahWithTwoDotsAbove\u{8a3}: 'ࢣ'
ArabicLetterFehWithDotBelowAndThreeDotsAbove\u{8a4}: 'ࢤ'
ArabicLetterQafWithDotBelow\u{8a5}: 'ࢥ'
ArabicLetterLamWithDoubleBar\u{8a6}: 'ࢦ'
ArabicLetterMeemWithThreeDotsAbove\u{8a7}: 'ࢧ'
ArabicLetterYehWithTwoDotsBelowAndHamzaAbove\u{8a8}: 'ࢨ'
ArabicLetterYehWithTwoDotsBelowAndDotAbove\u{8a9}: 'ࢩ'
ArabicLetterRehWithLoop\u{8aa}: 'ࢪ'
ArabicLetterWawWithDotWithin\u{8ab}: 'ࢫ'
ArabicLetterRohingyaYeh\u{8ac}: 'ࢬ'
ArabicLetterLowAlef\u{8ad}: 'ࢭ'
ArabicLetterDalWithThreeDotsBelow\u{8ae}: 'ࢮ'
ArabicLetterSadWithThreeDotsBelow\u{8af}: 'ࢯ'
ArabicLetterGafWithInvertedStroke\u{8b0}: 'ࢰ'
ArabicLetterStraightWaw\u{8b1}: 'ࢱ'
ArabicLetterZainWithInvertedVAbove\u{8b2}: 'ࢲ'
ArabicLetterAinWithThreeDotsBelow\u{8b3}: 'ࢳ'
ArabicLetterKafWithDotBelow\u{8b4}: 'ࢴ'
ArabicLetterBehWithSmallMeemAbove\u{8b6}: 'ࢶ'
ArabicLetterPehWithSmallMeemAbove\u{8b7}: 'ࢷ'
ArabicLetterTehWithSmallTehAbove\u{8b8}: 'ࢸ'
ArabicLetterRehWithSmallNoonAbove\u{8b9}: 'ࢹ'
ArabicLetterYehWithTwoDotsBelowAndSmallNoonAbove\u{8ba}: 'ࢺ'
ArabicLetterAfricanFeh\u{8bb}: 'ࢻ'
ArabicLetterAfricanQaf\u{8bc}: 'ࢼ'
ArabicLetterAfricanNoon\u{8bd}: 'ࢽ'
ArabicSmallLowWaw\u{8d3}: '࣓'
ArabicSmallHighWordArDashRub\u{8d4}: 'ࣔ'
ArabicSmallHighSad\u{8d5}: 'ࣕ'
ArabicSmallHighAin\u{8d6}: 'ࣖ'
ArabicSmallHighQaf\u{8d7}: 'ࣗ'
ArabicSmallHighNoonWithKasra\u{8d8}: 'ࣘ'
ArabicSmallLowNoonWithKasra\u{8d9}: 'ࣙ'
ArabicSmallHighWordAthDashThalatha\u{8da}: 'ࣚ'
ArabicSmallHighWordAsDashSajda\u{8db}: 'ࣛ'
ArabicSmallHighWordAnDashNisf\u{8dc}: 'ࣜ'
ArabicSmallHighWordSakta\u{8dd}: 'ࣝ'
ArabicSmallHighWordQif\u{8de}: 'ࣞ'
ArabicSmallHighWordWaqfa\u{8df}: 'ࣟ'
ArabicSmallHighFootnoteMarker\u{8e0}: '࣠'
ArabicSmallHighSignSafha\u{8e1}: '࣡'
ArabicDisputedEndOfAyah\u{8e2}: ''
ArabicTurnedDammaBelow\u{8e3}: 'ࣣ'
ArabicCurlyFatha\u{8e4}: 'ࣤ'
ArabicCurlyDamma\u{8e5}: 'ࣥ'
ArabicCurlyKasra\u{8e6}: 'ࣦ'
ArabicCurlyFathatan\u{8e7}: 'ࣧ'
ArabicCurlyDammatan\u{8e8}: 'ࣨ'
ArabicCurlyKasratan\u{8e9}: 'ࣩ'
ArabicToneOneDotAbove\u{8ea}: '࣪'
ArabicToneTwoDotsAbove\u{8eb}: '࣫'
ArabicToneLoopAbove\u{8ec}: '࣬'
ArabicToneOneDotBelow\u{8ed}: '࣭'
ArabicToneTwoDotsBelow\u{8ee}: '࣮'
ArabicToneLoopBelow\u{8ef}: '࣯'
ArabicOpenFathatan\u{8f0}: 'ࣰ'
ArabicOpenDammatan\u{8f1}: 'ࣱ'
ArabicOpenKasratan\u{8f2}: 'ࣲ'
ArabicSmallHighWaw\u{8f3}: 'ࣳ'
ArabicFathaWithRing\u{8f4}: 'ࣴ'
ArabicFathaWithDotAbove\u{8f5}: 'ࣵ'
ArabicKasraWithDotBelow\u{8f6}: 'ࣶ'
ArabicLeftArrowheadAbove\u{8f7}: 'ࣷ'
ArabicRightArrowheadAbove\u{8f8}: 'ࣸ'
ArabicLeftArrowheadBelow\u{8f9}: 'ࣹ'
ArabicRightArrowheadBelow\u{8fa}: 'ࣺ'
ArabicDoubleRightArrowheadAbove\u{8fb}: 'ࣻ'
ArabicDoubleRightArrowheadAboveWithDot\u{8fc}: 'ࣼ'
ArabicRightArrowheadAboveWithDot\u{8fd}: 'ࣽ'
ArabicDammaWithDot\u{8fe}: 'ࣾ'
Methods
impl ArabicExtendedA[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case